@@ -27,7 +27,8 @@ class OpenLeap():
                 SCREEN_TYPE='BLACK', 
                 SHOW_DATA_IN_CONSOLE=False, 
                 SHOW_DATA_ON_IMAGE=False, 
-                NORMALIZED_POSITION=True, 
+                NORMALIZED_POSITION=True,
+                GESTURE_MODEL='sign_language'
         ):
 
         super().__init__()
@@ -37,8 +38,13 @@ class OpenLeap():
                 'left' : self.Data()
                 }
 
+        if GESTURE_MODEL=='basic':
+            file_name='gesture_recognition.pkl'
+        elif GESTURE_MODEL=='sign_language':
+            file_name='sign_language_alphabet.pkl'
+
         this_dir, this_filename = os.path.split(__file__)  # Get path of data.pkl
-        data_path = os.path.join(this_dir, 'gesture_recognition.pkl')
+        data_path = os.path.join(this_dir, file_name)
         with open(data_path, 'rb') as f:
             self.model = pickle.load(f)
 
@@ -314,7 +320,8 @@ class OpenLeap():
                             self.data[hand_type].distance = self.get_distance_bettween_landmarks(
                                                                                         index, 
                                                                                         self.mp_hands.HandLandmark.INDEX_FINGER_TIP, 
-                                                                                        self.mp_hands.HandLandmark.THUMB_TIP
+                                                                                        self.mp_hands.HandLandmark.THUMB_TIP, 
+                                                                                        normalized=False
                                                                                         )
                                                                                     
                             self.data[hand_type].angle = self.get_angle(index, self.mp_hands.HandLandmark.MIDDLE_FINGER_MCP, unit='degree')
@@ -369,4 +376,4 @@ if __name__=='__main__':
         print(controller.relative_position['right'])
         if controller.detect_key('q'):
             controller.close_window()
-            break
\ No newline at end of file
+            break
